@@ -6,6 +6,7 @@ from bugsnag.notification import Notification
 
 configuration = Configuration()
 
+
 def configure(**options):
     """
     Configure the Bugsnag notifier application-wide settings.
@@ -33,14 +34,15 @@ def notify(exception, **options):
     """
     if isinstance(exception, (list, tuple)):
         # Exception tuples, eg. from sys.exc_info
-        exc_type, exc_value, bt = exception
         if not "traceback" in options:
-            options["traceback"] = bt
+            options["traceback"] = exception[2]
 
-        Notification(exc_value, configuration, RequestConfiguration.get_instance(), **options).deliver()
+        Notification(exception[1], configuration,
+                     RequestConfiguration.get_instance(), **options).deliver()
     else:
         # Exception objects
-        Notification(exception, configuration, RequestConfiguration.get_instance(), **options).deliver()
+        Notification(exception, configuration,
+                     RequestConfiguration.get_instance(), **options).deliver()
 
 
 def auto_notify(exception, **options):
@@ -70,5 +72,5 @@ def __bugsnag_excepthook(exctype, exception, traceback):
     auto_notify(exception, traceback=traceback)
     _old_excepthook(exctype, exception, traceback)
 
-_old_excepthook = sys.excepthook    
-sys.excepthook = __bugsnag_excepthook   
\ No newline at end of file
+_old_excepthook = sys.excepthook
+sys.excepthook = __bugsnag_excepthook
